@@ -351,8 +351,23 @@ static void applet_change_orient(PanelApplet *applet, PanelAppletOrient o, gpoin
 static void
 about (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-  static const char *authors[] = { "Alexandre Muiz <munizao@xprt.net", NULL };
   static GtkWidget *about_box = NULL;
+  GdkPixbuf   	   *pixbuf;
+  GError      	   *error     = NULL;
+  gchar            *file;
+   
+  const char *authors[] = {
+	  /* If your charset supports it, please use U00F1 to replace the "n"
+	   * in "Muniz". */
+	  _("Alexandre Muniz <munizao@xprt.net>"),
+	  NULL
+  };
+
+  const gchar *documenters[] = {
+	  NULL
+  };
+
+  const gchar *translator_credits = _("translator_credits");
 
   if (about_box != NULL)
   {
@@ -360,16 +375,32 @@ about (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 	  gdk_window_raise(about_box->window);
 	  return;
   }
-  about_box = gnome_about_new (_("Character Picker"),
+  
+  file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "charpick.png", FALSE, NULL);
+  pixbuf = gdk_pixbuf_new_from_file (file, &error);
+  g_free (file);
+   
+  if (error) {
+  	  g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+	  g_error_free (error);
+  }
+  
+  about_box = gnome_about_new (_("Character Palette"),
 			       CHARPICK_VERSION,
 			       _("Copyright (C) 1998"),
 			       _("Gnome Panel applet for selecting strange "
 			         "characters that are not on my keyboard. "
 				 "Released under GNU General Public Licence."),
 			       authors,
-			       NULL,
-			       NULL,
-			       NULL);
+			       documenters,
+			       strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			       pixbuf);
+  
+  if (pixbuf) 
+  	gdk_pixbuf_unref (pixbuf);
+   
+  gtk_window_set_wmclass (GTK_WINDOW (about_box), "character palette", "Character Palette");
+  gnome_window_icon_set_from_file (GTK_WINDOW (about_box), GNOME_ICONDIR"/charpick.png");
 
   gtk_signal_connect(GTK_OBJECT(about_box), "destroy",
 		     GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about_box);
@@ -381,11 +412,14 @@ about (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 static void
 help_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
-#ifdef FIXME
-        GnomeHelpMenuEntry help_entry = { "charpick_applet",
-                                          "index.html" };
-        gnome_help_display(NULL, &help_entry);
-#endif
+  GError *error = NULL;
+  gnome_help_display("char-palette",NULL,&error);
+
+  if (error) {
+    g_warning ("help error: %s\n", error->message);
+    g_error_free (error);
+    error = NULL;
+  }
 }
 
 static void
@@ -536,7 +570,7 @@ charpicker_applet_factory (PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_CharpickerApplet_Factory",
 			     PANEL_TYPE_APPLET,
-			     "Inserts characters",
+			     "char-palette",
 			     "0",
 			     charpicker_applet_factory,
 			     NULL)
