@@ -27,13 +27,11 @@ show_help(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
     GError *error = NULL;
     
-    gnome_help_display_desktop (NULL, "command-line", "command-line", NULL, &error);
+    gnome_help_display ("command-line", NULL, &error);
     if (error) {
     	g_warning ("help error: %s\n", error->message);
 	g_error_free (error);
     }
 
-    show_message((gchar *) _("still not ported")); 
-
     return;
 }
