@@ -39,6 +39,7 @@
 #include <fcntl.h>
 #include <string.h>
 #include <errno.h>
+#include <stdlib.h>
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -334,11 +335,7 @@ mixer_update_slider (MixerData *data)
 {
 	gint vol = data->vol;
 
-	if (IS_PANEL_HORIZONTAL (data->orientation)) {
-		vol = -vol;
-	} else {
-		vol = vol - VOLUME_MAX;
-	}
+	vol = -vol;
 	
 	gtk_adjustment_set_value (data->adj, vol);
 }
@@ -468,14 +465,32 @@ applet_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *dat
 
 
 static gboolean
-applet_scroll_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data)
+applet_scroll_event_cb (GtkWidget *widget, GdkEventScroll *event, MixerData *data)
 {
-       if (event->type = GDK_SCROLL) {
-               if (data->popup == NULL)
-                       mixer_popup_show (data);
-               return TRUE;
-       }
-       return FALSE;
+	gint direction; 
+	if (event->type != GDK_SCROLL ) {
+		return FALSE;
+	}
+
+	direction = event->direction;
+
+	switch(direction) {
+	case GDK_SCROLL_UP:
+		data->vol += 5;
+		break;
+	case GDK_SCROLL_DOWN:
+		data->vol -= 5;
+		break;
+	default:
+		break;
+	}
+
+	if (data->vol > VOLUME_MAX) data->vol = VOLUME_MAX;
+	if (data->vol < 0) data->vol = 0;
+
+	mixer_update_slider(data);
+
+	return TRUE;
 }
 
 static void
@@ -864,6 +879,9 @@ mixer_applet_create (PanelApplet *applet)
 	BonoboUIComponent *component;
 	const gchar *device;
 	gboolean retval;
+#ifdef SUN_API
+	gchar *ctl;
+#endif
 
 #ifdef OSS_API
 	/* /dev/sound/mixer for devfs */
@@ -875,8 +893,11 @@ mixer_applet_create (PanelApplet *applet)
 	}
 #endif
 #ifdef SUN_API
-	device = "/dev/audioctl";
-	retval = openMixer(device);
+	if (!(device = g_getenv("AUDIODEV")))
+		device = "/dev/audioctl";
+	ctl = g_strdup_printf("%sctl",device);
+	retval = openMixer(ctl);
+	g_free(ctl);
 #endif
 
 	if (!retval) {
